.. image :: https://i.imgur.com/yqfZiRG.png
   :align: center
   :alt: KAVK_API logo


.. image :: https://img.shields.io/pypi/v/kavk_api?style=for-the-badge
   :alt: PyPi version
   :target: https://pypi.python.org/pypi/kavk_api

.. image :: https://img.shields.io/pypi/l/kavk_api?style=for-the-badge
   :alt: MIT License
   :target: https://pypi.python.org/pypi/kavk_api

.. image :: https://img.shields.io/badge/VK-Contact-blue?style=for-the-badge
   :alt: https://vk.com/klm_ahmed
   :target: https://vk.com/klm_ahmed

=========

Установка
---------
``pip install kavk_api``

TODO:
-------
* типизация ивентов `BotLongPoll`_.
* работа над `UserLongPoll`_ (Типизация ивентов, фиксы багов)
* замена asyncio.run()

.. _BotLongPoll: https://dev.vk.com/api/community-events/json-schema
.. _UserLongPoll: https://dev.vk.com/api/user-long-poll/getting-started

Пример:
-------
.. code-block:: python

        import asyncio
        from kavk_api import Vk
        from kavk_api.longpoll import LongPoll

        async def main():
            vk = Vk('token')
            api = vk.get_api()
            longpoll = LongPoll(vk)
            await api.wall.post(message="Привет kavk_api!")
            async for event in longpoll.listen():
                print(event)
      
  
        asyncio.run(main())
